@@ -5,6 +5,7 @@
 
 import configparser as cfp
 from pathlib import Path
+
 from .dark_correction_utils import *  # noqa: F401,F403
 from .general import *
 from .plotting import *
@@ -14,6 +15,11 @@ cfg.read("vtf-calibration-config.cfg")
 
 home = Path.home()
 paths = cfg["paths"]
-RAW_DATA = Path(paths["raw_data_dir_location"]).expanduser() / paths["raw_data_dir_name"]
+RAW_DATA = (
+    Path(paths["raw_data_dir_location"]).expanduser() / paths["raw_data_dir_name"]
+)
 DKIST = Path(paths["dkist_dir_location"]).expanduser() / "DKIST"
 DATA = DKIST / "VTF" / "data"
+
+## Make this look in the config first
+TEST_DATA_SIZE = (1024, 1024)
